 _If this is a bug report, please fill in the following sections.
If this is a feature request, delete and describe what you would like with examples._

## What was wrong?

### Code that produced the error

```py
CODE_TO_REPRODUCE 
```

### Full error output 

```sh
ERROR_HERE 
```

### Expected Result

_This section may be deleted if the expectation is "don't crash"._

```sh
EXPECTED_RESULT
``` 

### Environment

```sh
# run this:
$ python -m eth_utils

# then copy the output here:
OUTPUT_HERE
``` 

## How can it be fixed?

Fill this section in if you know how this could or should be fixed.
